--AH:ScriptId=70b38356-1b66-4fb3-be29-3af9d1983748;2761
CREATE TABLE [BuildApprovalsReceived]
(
	[Approval_Id] INT IDENTITY(1, 1) NOT NULL,
	[Application_Id] INT NOT NULL,
	[Release_Number] RELEASENUMBER NOT NULL,
	[Build_Number] BUILDNUMBER NOT NULL,
	[Environment_Id] INT NOT NULL,
	[Original_Requirement_Id] INT NOT NULL,
	[RequirementType_Code] CHAR(2) NOT NULL,
	[User_Name] USERNAME NULL,
	[Comments_Text] NVARCHAR(1000) NULL,
	[Received_Date] DATETIME NOT NULL,
	[Requirement_Description] NVARCHAR(1000) NOT NULL,

	CONSTRAINT [PK__BuildApprovalsReceived]
		PRIMARY KEY ([Approval_Id]),

	CONSTRAINT [FK__BuildApprovalsReceived__Builds]
		FOREIGN KEY ([Application_Id], [Release_Number], [Build_Number])
		REFERENCES [Builds] ([Application_Id], [Release_Number], [Build_Number]),

	CONSTRAINT [FK__BuildApprovalsReceived__Environments]
		FOREIGN KEY ([Environment_Id])
		REFERENCES [Environments] ([Environment_Id]),

	CONSTRAINT [CK__BuildApprovalsReceived__RequirementType_Code]
		CHECK ([RequirementType_Code] IN ('AW', 'MW', 'AE', 'ME')),

	CONSTRAINT [CK__BuildApprovalsReceived__Comments_Text]
		CHECK ([Comments_Text] <> '' AND ([RequirementType_Code] IN ('MW', 'ME') OR [Comments_Text] IS NULL)),

	CONSTRAINT [CK__BuildApprovalsReceived__User_Name]
		CHECK (([User_Name] IS NULL AND [RequirementType_Code] IN ('AW', 'AE')) OR ([User_Name] IS NOT NULL AND [RequirementType_Code] IN ('MW', 'ME')))
)

INSERT INTO [BuildApprovalsReceived]
(
	[Application_Id],
	[Release_Number],
	[Build_Number],
	[Environment_Id],
	[Original_Requirement_Id],
	[RequirementType_Code],
	[User_Name],
	[Comments_Text],
	[Received_Date],
	[Requirement_Description]
)
SELECT BA.[Application_Id],
       BA.[Release_Number],
	   BA.[Build_Number],
	   BA.[Environment_Id],
	   [Original_Requirement_Id] = COALESCE(BPR.[Requirement_Id], 0),
	   [RequirementType_Code] = 'MW',
	   [User_Name],
	   [Comments_Text] = NULLIF(BA.[Comments_Text], ''),
	   BA.[Received_Date],
	   [Requirement_Description] = BA.[Approval_Description]
  FROM [BuildApprovals] BA
       INNER JOIN [BuildPromotions] BP --Only include data for completed promotions
	           ON BP.[Application_Id] = BA.[Application_Id]
			  AND BP.[Release_Number] = BA.[Release_Number]
			  AND BP.[Build_Number] = BA.[Build_Number]
			  AND BP.[Environment_Id] = BA.[Environment_Id]
	   INNER JOIN [Releases] R
	           ON R.[Application_Id] = BA.[Application_Id]
			  AND R.[Release_Number] = BA.[Release_Number]
	    LEFT JOIN [BuildPromotionRequirements] BPR
		       ON BPR.[Workflow_Id] = R.[Workflow_Id]
			  AND BPR.[Environment_Id] = BA.[Environment_Id]
			  AND (BPR.[Principal_Name] = BA.[User_Name] OR BPR.[Principal_Name] = BA.[Group_Name])
			  AND BPR.[Requirement_Description] = BA.[Approval_Description]
  WHERE BPR.[Requirement_Configuration] IS NULL
 ORDER BY BA.[Approval_Id]

DROP TABLE [BuildApprovals]