--AH:ScriptId=9d0bea23-3498-4270-988d-f4a6a93f1672;2948

CREATE TABLE [UserDirectories]
(
    [UserDirectory_Id] INT NOT NULL,
    [UserDirectory_Name] NVARCHAR(50) NOT NULL,
    [UserDirectory_Configuration] XML NOT NULL,

    CONSTRAINT [PK__UserDirectories] PRIMARY KEY ([UserDirectory_Id])
)
GO

INSERT [UserDirectories] ([UserDirectory_Id], [UserDirectory_Name], [UserDirectory_Configuration])
SELECT 1, 'Built-In', '<Inedo.BuildMaster.Web.Security.UserDirectory.BuiltInDirectory Assembly="BuildMaster"><Properties /></Inedo.BuildMaster.Web.Security.UserDirectory.BuiltInDirectory>' UNION ALL
SELECT 2, 'LDAP', '<Inedo.BuildMaster.Web.Security.UserDirectory.LdapDirectory Assembly="BuildMaster"><Properties /></Inedo.BuildMaster.Web.Security.UserDirectory.LdapDirectory>' UNION ALL
SELECT 3, 'Active Directory with Multiple Domains', '<Inedo.BuildMaster.Web.Security.UserDirectory.MultiDomainActiveDirectory Assembly="BuildMaster"><Properties /></Inedo.BuildMaster.Web.Security.UserDirectory.MultiDomainActiveDirectory>'
GO

ALTER TABLE [Privileges]
  ADD [UserDirectory_Id] INT NULL
GO

UPDATE [Privileges] 
   SET [UserDirectory_Id] = [Directory_Provider_Id]
GO

-- safety net for custom directory providers, set privilege to built-in directory
UPDATE [Privileges] 
   SET [UserDirectory_Id] = 1
 WHERE [UserDirectory_Id] IS NULL OR [UserDirectory_Id] > 3
GO

ALTER TABLE [Privileges] 
  DROP CONSTRAINT [FK__Privileges__Providers]
GO

ALTER TABLE [Privileges]
  DROP CONSTRAINT [UQ__Privileges]
GO 

ALTER TABLE [Privileges]
  DROP COLUMN [Directory_Provider_Id]
GO

ALTER TABLE [Privileges]
  ALTER COLUMN [UserDirectory_Id] INT NOT NULL
GO

ALTER TABLE [Privileges] 
  ADD CONSTRAINT [FK__Privileges__UserDirectories] 
     FOREIGN KEY ([UserDirectory_Id]) REFERENCES [UserDirectories] ([UserDirectory_Id])
GO

ALTER TABLE [Privileges] 
  ADD CONSTRAINT [UQ__Privileges] UNIQUE NONCLUSTERED 
  (
	  [UserDirectory_Id],
	  [Principal_Name],
	  [PrincipalType_Code],
	  [Role_Id],
	  [ApplicationGroup_Id],
	  [Application_Id],
	  [Environment_Id],
	  [PrivilegeType_Code]
  )
GO

DELETE [Providers] WHERE [ProviderType_Code] = 'D'
GO

ALTER TABLE [Providers]
  DROP CONSTRAINT [CK__Providers__ProviderType_Code_Domain]
GO

ALTER TABLE [Providers]
  ADD CONSTRAINT [CK__Providers__ProviderType_Code_Domain] CHECK ([ProviderType_Code] IN ('S', 'I', 'B'))
GO

UPDATE [Configuration]
   SET [Key_Name] = 'UserDirectoryId',
       [Description_Text] = 'The ID of the user directory provider BuildMaster is currently using. Valid values are: 1=built-in, 2=LDAP, 3=Active Directory (multiple domain)'
 WHERE [Key_Name] = 'DirectoryProvider'
GO

UPDATE [Configuration]
   SET [Description_Text] = 'Indicates whether Windows Integrated Authentication should be used instead of BuildMaster''s forms-based authentication. This value should normally be set to "false" if UserDirectoryId is set to 1. If set to "true" with UserDirectoryId > 1, entering login credentials is not required. IIS-hosted instances require additional configuration, consult the BuildMaster documentation for more information.'
 WHERE [Key_Name] = 'IntegratedAuthenticationEnabled'
GO
