EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'ConfigurationFiles_GetConfigurationFile',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'DataSet',
    /* DataTableNames_Csv      */ 'ConfigurationFiles_Extended,ConfigurationFileInstances_Extended,ConfigurationFileVersions_Combined,ConfigurationFileVersions_ModifiedInstances',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets a configuration file and all of its instances.'
GO


IF OBJECT_ID('[ConfigurationFiles_GetConfigurationFile]') IS NOT NULL DROP PROCEDURE [ConfigurationFiles_GetConfigurationFile]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ConfigurationFiles_GetConfigurationFile]
(
	@ConfigurationFile_Id INT,
	@IncludeInactiveInstances_Indicator YNINDICATOR = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	SELECT *
	  FROM [ConfigurationFiles_Extended]
	 WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id
	
	IF (@@ROWCOUNT = 0) BEGIN
		RAISERROR('Configuration file %i does not exist.', 16, 1, @ConfigurationFile_Id)
		RETURN
	END

	SELECT CFI.*
	  FROM [ConfigurationFileInstances_Extended] CFI
	       LEFT JOIN [Environments] E
		           ON E.[Environment_Id] = CFI.[Environment_Id]
	 WHERE CFI.[ConfigurationFile_Id] = @ConfigurationFile_Id
	   AND (CFI.[Active_Indicator] = 'Y' OR @IncludeInactiveInstances_Indicator = 'Y')
	 ORDER BY CFI.[Template_Indicator], E.[Display_Sequence], CFI.[Instance_Name]

	SELECT *
	  FROM [ConfigurationFileVersions_Combined]
	 WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id

	SELECT *
	  FROM [ConfigurationFileVersions_ModifiedInstances] CFVMI
	 WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id

END
GO

GRANT EXECUTE ON [ConfigurationFiles_GetConfigurationFile] TO [BuildMasterUser_Role]