EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'DatabaseChangeScripts_CreateOrUpdateChangeScript',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Script_Id',
    /* Description_Text        */ 'Creates or edits a database change script.'
GO

IF OBJECT_ID('[DatabaseChangeScripts_CreateOrUpdateChangeScript]') IS NOT NULL DROP PROCEDURE [DatabaseChangeScripts_CreateOrUpdateChangeScript]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [DatabaseChangeScripts_CreateOrUpdateChangeScript]
(
	@Application_Id INT,
	@Release_Number RELEASENUMBER,
	@Deployable_Id INT,
	@Script_Name VARCHAR(250),
	@Script_Text NVARCHAR(MAX),
	@Active_Indicator YNINDICATOR,
	@Script_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Release_Id INT
	SELECT @Release_Id = [Release_Id]
	  FROM [Releases]
	 WHERE [Application_Id] = @Application_Id
	   AND [Release_Number] = @Release_Number

	IF @Script_Id IS NULL
	BEGIN
		INSERT INTO [DatabaseChangeScripts]
		(
			[Release_Id],
			[Deployable_Id],
			[Script_Name],
			[Script_Text],
			[Active_Indicator],
			[CreatedBy_User_Name],
			[CreatedOn_Date],
			[ModifiedBy_User_Name],
			[ModifiedOn_Date],
			[Script_Guid]
		)
		VALUES
		(
			@Release_Id,
			@Deployable_Id,
			@Script_Name,
			@Script_Text,
			@Active_Indicator,
			dbo.Session_GetUserName(),
			GETUTCDATE(),
			dbo.Session_GetUserName(),
			GETUTCDATE(),
			NEWID()
		)

		SET @Script_Id = SCOPE_IDENTITY()

		EXEC [Events_RaiseEvent] 'DBSNWS', @Application_Id, @Script_Id
	END
	ELSE
	BEGIN
		UPDATE [DatabaseChangeScripts]
		   SET [Release_Id] = @Release_Id,
		       [Deployable_Id] = @Deployable_Id,
			   [Script_Name] = @Script_Name,
			   [Script_Text] = @Script_Text,
			   [Active_Indicator] = @Active_Indicator,
			   [ModifiedBy_User_Name] = dbo.Session_GetUserName(),
			   [ModifiedOn_Date] = GETUTCDATE()
		 WHERE [Script_Id] = @Script_Id

		EXEC [Events_RaiseEvent] 'DBSMDS', @Application_Id, @Script_Id
	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [DatabaseChangeScripts_CreateOrUpdateChangeScript] TO [BuildMasterUser_Role]
