EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Rafts_CreateOrUpdateRaft',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Raft_Id',
    /* Description_Text        */ 'Creates a new raft, or updates an existing one.'
GO

IF OBJECT_ID('[Rafts_CreateOrUpdateRaft]') IS NOT NULL DROP PROCEDURE [Rafts_CreateOrUpdateRaft]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Rafts_CreateOrUpdateRaft]
(
    @Raft_Name VARCHAR(50),
    @Environment_Id INT,
    @Raft_Configuration XML,
    @Raft_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @Raft_Id IS NULL
	BEGIN
		INSERT INTO [Rafts] 
		(
			[Raft_Name],
			[Environment_Id],
            [Raft_Configuration]
		)
		VALUES
		(
            @Raft_Name,
			@Environment_Id,
            @Raft_Configuration			
		)
		SET @Raft_Id = SCOPE_IDENTITY()
	END
	ELSE
	BEGIN
		UPDATE [Rafts]
		   SET [Raft_Name] = @Raft_Name,
		       [Environment_Id] = @Environment_Id,
			   [Raft_Configuration] = @Raft_Configuration
		 WHERE [Raft_Id] = @Raft_Id
	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Rafts_CreateOrUpdateRaft] TO [BuildMasterUser_Role]
